@@ -15,18 +15,10 @@
 """Create / interact with Google Cloud Storage connections."""
 
 import functools
-import os
-import pkg_resources  # type: ignore
-
-from google.cloud import _http  # type: ignore
 
+from google.cloud import _http
 from google.cloud.storage import __version__
-
-
-if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE") == "true":  # pragma: NO COVER
-    release = pkg_resources.get_distribution("google-cloud-core").parsed_version
-    if release < pkg_resources.parse_version("1.6.0"):
-        raise ImportError("google-cloud-core >= 1.6.0 is required to use mTLS feature")
+from google.cloud.storage import _helpers
 
 
 class Connection(_http.JSONConnection):
@@ -68,6 +60,7 @@ class Connection(_http.JSONConnection):
 
     def api_request(self, *args, **kwargs):
         retry = kwargs.pop("retry", None)
+        kwargs["extra_api_info"] = _helpers._get_invocation_id()
         call = functools.partial(super(Connection, self).api_request, *args, **kwargs)
         if retry:
             # If this is a ConditionalRetryPolicy, check conditions.
