@@ -39,7 +39,10 @@ def _check_blob_hash(blob, info):
 
 
 def test_large_file_write_from_stream(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("LargeFile")
 
@@ -52,7 +55,10 @@ def test_large_file_write_from_stream(
 
 
 def test_large_file_write_from_stream_w_checksum(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("LargeFile")
 
@@ -65,7 +71,10 @@ def test_large_file_write_from_stream_w_checksum(
 
 
 def test_large_file_write_from_stream_w_failed_checksum(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("LargeFile")
 
@@ -88,7 +97,11 @@ def test_large_file_write_from_stream_w_failed_checksum(
 
 
 def test_large_file_write_from_stream_w_encryption_key(
-    storage_client, shared_bucket, blobs_to_delete, file_data, service_account,
+    storage_client,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("LargeFile", encryption_key=encryption_key)
 
@@ -110,7 +123,10 @@ def test_large_file_write_from_stream_w_encryption_key(
 
 
 def test_small_file_write_from_filename(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("SmallFile")
 
@@ -122,7 +138,10 @@ def test_small_file_write_from_filename(
 
 
 def test_small_file_write_from_filename_with_checksum(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("SmallFile")
 
@@ -134,7 +153,10 @@ def test_small_file_write_from_filename_with_checksum(
 
 
 def test_small_file_write_from_filename_with_failed_checksum(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("SmallFile")
 
@@ -235,7 +257,10 @@ def test_blob_crud_w_user_project(
 
 
 def test_blob_crud_w_etag_match(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     wrong_etag = "kittens"
 
@@ -281,7 +306,10 @@ def test_blob_crud_w_etag_match(
 
 
 def test_blob_crud_w_generation_match(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     wrong_generation_number = 6
     wrong_metageneration_number = 9
@@ -373,7 +401,10 @@ def test_blob_acl_w_user_project(
 
 
 def test_blob_acl_w_metageneration_match(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     wrong_metageneration_number = 9
     wrong_generation_number = 6
@@ -408,7 +439,10 @@ def test_blob_acl_w_metageneration_match(
 
 
 def test_blob_acl_upload_predefined(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     control = shared_bucket.blob("logo")
     control_info = file_data["logo"]
@@ -438,7 +472,10 @@ def test_blob_acl_upload_predefined(
 
 
 def test_blob_patch_metadata(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     filename = file_data["logo"]["path"]
     blob_name = os.path.basename(filename)
@@ -467,7 +504,9 @@ def test_blob_patch_metadata(
 
 
 def test_blob_direct_write_and_read_into_file(
-    shared_bucket, blobs_to_delete, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    service_account,
 ):
     payload = b"Hello World"
     blob = shared_bucket.blob("MyBuffer")
@@ -489,7 +528,9 @@ def test_blob_direct_write_and_read_into_file(
 
 
 def test_blob_download_w_generation_match(
-    shared_bucket, blobs_to_delete, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    service_account,
 ):
     wrong_generation_number = 6
 
@@ -522,7 +563,9 @@ def test_blob_download_w_generation_match(
 
 
 def test_blob_download_w_failed_crc32c_checksum(
-    shared_bucket, blobs_to_delete, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    service_account,
 ):
     blob = shared_bucket.blob("FailedChecksumBlob")
     payload = b"Hello World"
@@ -555,7 +598,9 @@ def test_blob_download_w_failed_crc32c_checksum(
 
 
 def test_blob_download_as_text(
-    shared_bucket, blobs_to_delete, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    service_account,
 ):
     blob = shared_bucket.blob("MyBuffer")
     payload = "Hello World"
@@ -571,7 +616,9 @@ def test_blob_download_as_text(
 
 
 def test_blob_upload_w_gzip_encoded_download_raw(
-    shared_bucket, blobs_to_delete, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    service_account,
 ):
     payload = b"DEADBEEF" * 1000
     raw_stream = io.BytesIO()
@@ -592,7 +639,10 @@ def test_blob_upload_w_gzip_encoded_download_raw(
 
 
 def test_blob_upload_from_file_resumable_with_generation(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("LargeFile")
     wrong_generation = 3
@@ -616,18 +666,23 @@ def test_blob_upload_from_file_resumable_with_generation(
     with pytest.raises(exceptions.PreconditionFailed):
         with open(info["path"], "rb") as file_obj:
             blob.upload_from_file(
-                file_obj, if_generation_match=wrong_generation,
+                file_obj,
+                if_generation_match=wrong_generation,
             )
 
     with pytest.raises(exceptions.PreconditionFailed):
         with open(info["path"], "rb") as file_obj:
             blob.upload_from_file(
-                file_obj, if_metageneration_match=wrong_meta_generation,
+                file_obj,
+                if_metageneration_match=wrong_meta_generation,
             )
 
 
 def test_blob_upload_from_string_w_owner(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("MyBuffer")
     payload = b"Hello World"
@@ -642,7 +697,10 @@ def test_blob_upload_from_string_w_owner(
 
 
 def test_blob_upload_from_string_w_custom_time(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("CustomTimeBlob")
     payload = b"Hello World"
@@ -658,7 +716,10 @@ def test_blob_upload_from_string_w_custom_time(
 
 
 def test_blob_upload_from_string_w_custom_time_no_micros(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     # Test that timestamps without microseconds are treated correctly by
     # custom_time encoding/decoding.
@@ -676,7 +737,10 @@ def test_blob_upload_from_string_w_custom_time_no_micros(
 
 
 def test_blob_upload_download_crc32_md5_hash(
-    shared_bucket, blobs_to_delete, file_data, service_account,
+    shared_bucket,
+    blobs_to_delete,
+    file_data,
+    service_account,
 ):
     blob = shared_bucket.blob("MyBuffer")
     payload = b"Hello World"
@@ -693,8 +757,8 @@ def test_blob_upload_download_crc32_md5_hash(
 @pytest.mark.parametrize(
     "blob_name,payload",
     [
-        (u"Caf\u00e9", b"Normalization Form C"),
-        (u"Cafe\u0301", b"Normalization Form D"),
+        ("Caf\u00e9", b"Normalization Form C"),
+        ("Cafe\u0301", b"Normalization Form D"),
     ],
 )
 def test_blob_w_unicode_names(blob_name, payload, shared_bucket, blobs_to_delete):
@@ -841,7 +905,8 @@ def test_blob_compose_w_source_generation_match(shared_bucket, blobs_to_delete):
 
     with pytest.raises(exceptions.PreconditionFailed):
         original.compose(
-            [original, to_append], if_source_generation_match=wrong_source_generations,
+            [original, to_append],
+            if_source_generation_match=wrong_source_generations,
         )
 
     original.compose(
