@@ -117,7 +117,9 @@ def test_bucket_update_labels(storage_client, buckets_to_delete):
 
 
 def test_bucket_get_set_iam_policy(
-    storage_client, buckets_to_delete, service_account,
+    storage_client,
+    buckets_to_delete,
+    service_account,
 ):
     from google.cloud.storage.iam import STORAGE_OBJECT_VIEWER_ROLE
     from google.api_core.exceptions import BadRequest
@@ -177,7 +179,10 @@ def test_bucket_crud_w_requester_pays(storage_client, buckets_to_delete, user_pr
     assert created.name == bucket_name
     assert created.requester_pays
 
-    with_user_project = storage_client.bucket(bucket_name, user_project=user_project,)
+    with_user_project = storage_client.bucket(
+        bucket_name,
+        user_project=user_project,
+    )
 
     try:
         # Exercise 'buckets.get' w/ userProject.
@@ -210,7 +215,8 @@ def test_bucket_acls_iam_w_user_project(
 ):
     bucket_name = _helpers.unique_name("acl-w-user-project")
     created = _helpers.retry_429_503(storage_client.create_bucket)(
-        bucket_name, requester_pays=True,
+        bucket_name,
+        requester_pays=True,
     )
     buckets_to_delete.append(created)
 
@@ -282,7 +288,10 @@ def test_bucket_acls_w_metageneration_match(storage_client, buckets_to_delete):
 
 
 def test_bucket_copy_blob(
-    storage_client, buckets_to_delete, blobs_to_delete, user_project,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
+    user_project,
 ):
     payload = b"DEADBEEF"
     bucket_name = _helpers.unique_name("copy-blob")
@@ -304,7 +313,10 @@ def test_bucket_copy_blob(
 
 
 def test_bucket_copy_blob_w_user_project(
-    storage_client, buckets_to_delete, blobs_to_delete, user_project,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
+    user_project,
 ):
     payload = b"DEADBEEF"
     bucket_name = _helpers.unique_name("copy-w-requester-pays")
@@ -330,7 +342,9 @@ def test_bucket_copy_blob_w_user_project(
 
 
 def test_bucket_copy_blob_w_generation_match(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     payload = b"DEADBEEF"
     bucket_name = _helpers.unique_name("generation-match")
@@ -345,7 +359,10 @@ def test_bucket_copy_blob_w_generation_match(
     dest_bucket = storage_client.bucket(bucket_name)
 
     new_blob = dest_bucket.copy_blob(
-        blob, dest_bucket, "simple-copy", if_source_generation_match=blob.generation,
+        blob,
+        dest_bucket,
+        "simple-copy",
+        if_source_generation_match=blob.generation,
     )
     blobs_to_delete.append(new_blob)
 
@@ -353,7 +370,9 @@ def test_bucket_copy_blob_w_generation_match(
 
 
 def test_bucket_copy_blob_w_metageneration_match(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     payload = b"DEADBEEF"
     bucket_name = _helpers.unique_name("generation-match")
@@ -381,7 +400,10 @@ def test_bucket_copy_blob_w_metageneration_match(
 
 
 def test_bucket_get_blob_with_user_project(
-    storage_client, buckets_to_delete, blobs_to_delete, user_project,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
+    user_project,
 ):
     blob_name = "blob-name"
     payload = b"DEADBEEF"
@@ -413,7 +435,10 @@ def test_bucket_list_blobs(listable_bucket, listable_filenames):
 
 @_helpers.retry_failures
 def test_bucket_list_blobs_w_user_project(
-    storage_client, listable_bucket, listable_filenames, user_project,
+    storage_client,
+    listable_bucket,
+    listable_filenames,
+    user_project,
 ):
     with_user_project = storage_client.bucket(
         listable_bucket.name, user_project=user_project
@@ -545,7 +570,8 @@ def test_bucket_list_blobs_hierarchy_third_level(hierarchy_bucket, hierarchy_fil
 
 @_helpers.retry_failures
 def test_bucket_list_blobs_hierarchy_w_include_trailing_delimiter(
-    hierarchy_bucket, hierarchy_filenames,
+    hierarchy_bucket,
+    hierarchy_filenames,
 ):
     expected_names = ["file01.txt", "parent/"]
     expected_prefixes = set(["parent/"])
@@ -562,7 +588,9 @@ def test_bucket_list_blobs_hierarchy_w_include_trailing_delimiter(
 
 
 def test_bucket_w_retention_period(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     period_secs = 10
     bucket_name = _helpers.unique_name("w-retention-period")
@@ -613,7 +641,9 @@ def test_bucket_w_retention_period(
 
 
 def test_bucket_w_default_event_based_hold(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     bucket_name = _helpers.unique_name("w-def-ebh")
     bucket = _helpers.retry_429_503(storage_client.create_bucket)(bucket_name)
@@ -670,7 +700,9 @@ def test_bucket_w_default_event_based_hold(
 
 
 def test_blob_w_temporary_hold(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     bucket_name = _helpers.unique_name("w-tmp-hold")
     bucket = _helpers.retry_429_503(storage_client.create_bucket)(bucket_name)
@@ -702,7 +734,8 @@ def test_blob_w_temporary_hold(
 
 
 def test_bucket_lock_retention_policy(
-    storage_client, buckets_to_delete,
+    storage_client,
+    buckets_to_delete,
 ):
     period_secs = 10
     bucket_name = _helpers.unique_name("loc-ret-policy")
@@ -728,7 +761,9 @@ def test_bucket_lock_retention_policy(
 
 
 def test_new_bucket_w_ubla(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     bucket_name = _helpers.unique_name("new-w-ubla")
     bucket = storage_client.bucket(bucket_name)
@@ -765,7 +800,9 @@ def test_new_bucket_w_ubla(
 
 
 def test_ubla_set_unset_preserves_acls(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     bucket_name = _helpers.unique_name("ubla-acls")
     bucket = _helpers.retry_429_503(storage_client.create_bucket)(bucket_name)
@@ -806,7 +843,9 @@ def test_ubla_set_unset_preserves_acls(
 
 
 def test_new_bucket_created_w_inherited_pap(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     from google.cloud.storage import constants
 
@@ -857,7 +896,9 @@ def test_new_bucket_created_w_inherited_pap(
 
 @pytest.mark.skip(reason="Unspecified PAP is changing to inherited")
 def test_new_bucket_created_w_enforced_pap(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     from google.cloud.storage import constants
 
@@ -888,7 +929,9 @@ def test_new_bucket_created_w_enforced_pap(
 
 
 def test_new_bucket_with_rpo(
-    storage_client, buckets_to_delete, blobs_to_delete,
+    storage_client,
+    buckets_to_delete,
+    blobs_to_delete,
 ):
     from google.cloud.storage import constants
 
