@@ -33,7 +33,8 @@ def test_anonymous_client_access_to_public_bucket():
     anonymous_client = Client.create_anonymous_client()
     bucket = anonymous_client.bucket(public_bucket)
     (blob,) = _helpers.retry_429_503(anonymous_client.list_blobs)(
-        bucket, max_results=1,
+        bucket,
+        max_results=1,
     )
     with tempfile.TemporaryFile() as stream:
         _helpers.retry_429_503(blob.download_to_file)(stream)
@@ -63,6 +64,27 @@ def test_create_bucket_simple(storage_client, buckets_to_delete):
     assert created.name == new_bucket_name
 
 
+def test_create_bucket_dual_region(storage_client, buckets_to_delete):
+    from google.cloud.storage.constants import DUAL_REGION_LOCATION_TYPE
+
+    new_bucket_name = _helpers.unique_name("dual-region-bucket")
+    region_1 = "US-EAST1"
+    region_2 = "US-WEST1"
+    dual_region = f"{region_1}+{region_2}"
+
+    with pytest.raises(exceptions.NotFound):
+        storage_client.get_bucket(new_bucket_name)
+
+    created = _helpers.retry_429_503(storage_client.create_bucket)(
+        new_bucket_name, location=dual_region
+    )
+    buckets_to_delete.append(created)
+
+    assert created.name == new_bucket_name
+    assert created.location == dual_region
+    assert created.location_type == DUAL_REGION_LOCATION_TYPE
+
+
 def test_list_buckets(storage_client, buckets_to_delete):
     buckets_to_create = [
         _helpers.unique_name("new"),
@@ -85,7 +107,10 @@ def test_list_buckets(storage_client, buckets_to_delete):
 
 
 def test_download_blob_to_file_w_uri(
-    storage_client, shared_bucket, blobs_to_delete, service_account,
+    storage_client,
+    shared_bucket,
+    blobs_to_delete,
+    service_account,
 ):
     blob = shared_bucket.blob("MyBuffer")
     payload = b"Hello World"
@@ -106,7 +131,10 @@ def test_download_blob_to_file_w_uri(
 
 
 def test_download_blob_to_file_w_etag(
-    storage_client, shared_bucket, blobs_to_delete, service_account,
+    storage_client,
+    shared_bucket,
+    blobs_to_delete,
+    service_account,
 ):
     filename = "kittens"
     blob = shared_bucket.blob(filename)
@@ -140,6 +168,8 @@ def test_download_blob_to_file_w_etag(
 
     buffer = io.BytesIO()
     storage_client.download_blob_to_file(
-        "gs://" + shared_bucket.name + "/" + filename, buffer, if_etag_match=blob.etag,
+        "gs://" + shared_bucket.name + "/" + filename,
+        buffer,
+        if_etag_match=blob.etag,
     )
     assert buffer.getvalue() == payload
