@@ -13,9 +13,13 @@
 # limitations under the License.
 
 import unittest
+from unittest.mock import patch
 
 import mock
 
+from google.cloud.storage import _helpers
+from tests.unit.test__helpers import GCCL_INVOCATION_TEST_CONST
+
 
 class TestConnection(unittest.TestCase):
     @staticmethod
@@ -44,12 +48,17 @@ class TestConnection(unittest.TestCase):
 
         conn = self._make_one(client)
         req_data = "hey-yoooouuuuu-guuuuuyyssss"
-        result = conn.api_request("GET", "/rainbow", data=req_data, expect_json=False)
+        with patch.object(
+            _helpers, "_get_invocation_id", return_value=GCCL_INVOCATION_TEST_CONST
+        ):
+            result = conn.api_request(
+                "GET", "/rainbow", data=req_data, expect_json=False
+            )
         self.assertEqual(result, data)
 
         expected_headers = {
             "Accept-Encoding": "gzip",
-            base_http.CLIENT_INFO_HEADER: conn.user_agent,
+            base_http.CLIENT_INFO_HEADER: f"{conn.user_agent} {GCCL_INVOCATION_TEST_CONST}",
             "User-Agent": conn.user_agent,
         }
         expected_uri = conn.build_api_url("/rainbow")
